class AlreadyInvited(Exception):
    """User has a valid, pending invitation"""
    pass


class AlreadyAccepted(Exception):
    """User has already accepted an invitation"""
    pass


class UserRegisteredEmail(Exception):
    """This email is already registered by a site user """
    pass



from django.template.loader import render_to_string
from django.contrib import messages
from django.conf import settings
from django.template import TemplateDoesNotExist
from django.core.mail import EmailMultiAlternatives, EmailMessage
from django.contrib.sites.models import Site

try:
    from django.utils.encoding import force_text
except ImportError:
    from django.utils.encoding import force_unicode as force_text

from .app_settings import app_settings
from .utils import import_attribute


# Code credits here to django-allauth
class BaseInvitationsAdapter(object):

    def stash_verified_email(self, request, email):
        request.session['account_verified_email'] = email

    def unstash_verified_email(self, request):
        ret = request.session.get('account_verified_email')
        request.session['account_verified_email'] = None
        return ret

    def format_email_subject(self, subject):
        site = Site.objects.get_current()
        prefix = "[{name}] ".format(name=site.name)
        return prefix + force_text(subject)

    def render_mail(self, template_prefix, email, context):
        """
        Renders an e-mail to `email`.  `template_prefix` identifies the
        e-mail that is to be sent, e.g. "account/email/email_confirmation"
        """
        subject = render_to_string('{0}_subject.txt'.format(template_prefix),
                                   context)
        # remove superfluous line breaks
        subject = " ".join(subject.splitlines()).strip()
        subject = self.format_email_subject(subject)

        bodies = {}
        for ext in ['html', 'txt']:
            try:
                template_name = '{0}_message.{1}'.format(template_prefix, ext)
                bodies[ext] = render_to_string(template_name,
                                               context).strip()
            except TemplateDoesNotExist:
                if ext == 'txt' and not bodies:
                    # We need at least one body
                    raise
        if 'txt' in bodies:
            msg = EmailMultiAlternatives(subject,
                                         bodies['txt'],
                                         settings.DEFAULT_FROM_EMAIL,
                                         [email])
            if 'html' in bodies:
                msg.attach_alternative(bodies['html'], 'text/html')
        else:
            msg = EmailMessage(subject,
                               bodies['html'],
                               settings.DEFAULT_FROM_EMAIL,
                               [email])
            msg.content_subtype = 'html'  # Main content is now text/html
        return msg

    def send_mail(self, template_prefix, email, context):
        msg = self.render_mail(template_prefix, email, context)
        msg.send()

    def is_open_for_signup(self, request):
        if hasattr(request, 'session') and request.session.get(
                'account_verified_email'):
            return True
        elif app_settings.INVITATION_ONLY is True:
            # Site is ONLY open for invites
            return False
        else:
            # Site is open to signup
            return True

    def clean_email(self, email):
        """
        Validates an email value. You can hook into this if you want to
        (dynamically) restrict what email addresses can be chosen.
        """
        return email

    def add_message(self, request, level, message_template,
                    message_context=None, extra_tags=''):
        """
        Wrapper of `django.contrib.messages.add_message`, that reads
        the message text from a template.
        """
        if 'django.contrib.messages' in settings.INSTALLED_APPS:
            try:
                if message_context is None:
                    message_context = {}
                message = render_to_string(message_template,
                                           message_context).strip()
                if message:
                    messages.add_message(request, level, message,
                                         extra_tags=extra_tags)
            except TemplateDoesNotExist:
                pass


def get_invitations_adapter():
    # Compatibility with legacy allauth only version.
    LEGACY_ALLAUTH = hasattr(settings, 'ACCOUNT_ADAPTER') and \
        settings.ACCOUNT_ADAPTER == 'invitations.models.InvitationsAdapter'
    if LEGACY_ALLAUTH:
        # defer to allauth
        from allauth.account.adapter import get_adapter
        return get_adapter()
    else:
        # load an adapter from elsewhere
        return import_attribute(app_settings.ADAPTER)()



import json

from django.views.generic import FormView, View
from django.views.generic.detail import SingleObjectMixin
from django.contrib import messages
from django.http import Http404, HttpResponse
from django.shortcuts import redirect
from django.core.exceptions import ValidationError
from django.core.validators import validate_email

from braces.views import LoginRequiredMixin

from .forms import InviteForm, CleanEmailMixin
from .models import Invitation
from . import signals
from .exceptions import AlreadyInvited, AlreadyAccepted, UserRegisteredEmail
from .app_settings import app_settings
from .adapters import get_invitations_adapter


class SendInvite(LoginRequiredMixin, FormView):
    template_name = 'invitations/forms/_invite.html'
    form_class = InviteForm

    def form_valid(self, form):
        email = form.cleaned_data["email"]

        try:
            invite = form.save(email)
            # inviter can also be set on create
            if not invite.inviter:
                invite.inviter = self.request.user
                invite.save()
            invite.send_invitation(self.request)
        except Exception:
            return self.form_invalid(form)

        return self.render_to_response(
            self.get_context_data(
                success_message='%s has been invited' % email))

    def form_invalid(self, form):
        return self.render_to_response(self.get_context_data(form=form))


class SendJSONInvite(LoginRequiredMixin, View):
    http_method_names = [u'post']

    def dispatch(self, request, *args, **kwargs):
        if app_settings.ALLOW_JSON_INVITES:
            return super(SendJSONInvite, self).dispatch(
                request, *args, **kwargs)
        else:
            raise Http404

    def post(self, request, *args, **kwargs):
        status_code = 400
        invitees = json.loads(request.body.decode())
        response = {'valid': [], 'invalid': []}
        if isinstance(invitees, list):
            for invitee in invitees:
                try:
                    validate_email(invitee)
                    CleanEmailMixin().validate_invitation(invitee)
                    invite = Invitation.create(invitee)
                except(ValueError, KeyError):
                    pass
                except(ValidationError):
                    response['invalid'].append({
                        invitee: 'invalid email'})
                except(AlreadyAccepted):
                    response['invalid'].append({
                        invitee: 'already accepted'})
                except(AlreadyInvited):
                    response['invalid'].append(
                        {invitee: 'pending invite'})
                except(UserRegisteredEmail):
                    response['invalid'].append(
                        {invitee: 'user registered email'})
                else:
                    invite.send_invitation(request)
                    response['valid'].append({invitee: 'invited'})

        if response['valid']:
            status_code = 201

        return HttpResponse(
            json.dumps(response),
            status=status_code, content_type='application/json')


class AcceptInvite(SingleObjectMixin, View):
    form_class = InviteForm

    def get(self, *args, **kwargs):
        if app_settings.CONFIRM_INVITE_ON_GET:
            return self.post(*args, **kwargs)
        else:
            raise Http404()

    def post(self, *args, **kwargs):
        self.object = invitation = self.get_object()
        invitation.accepted = True
        invitation.save()
        get_invitations_adapter().stash_verified_email(
            self.request, invitation.email)

        signals.invite_accepted.send(sender=self.__class__,
                                     request=self.request,
                                     email=invitation.email)

        get_invitations_adapter().add_message(
            self.request,
            messages.SUCCESS,
            'invitations/messages/invite_accepted.txt',
            {'email': invitation.email})

        return redirect(app_settings.SIGNUP_REDIRECT)

    def get_object(self, queryset=None):
        if queryset is None:
            queryset = self.get_queryset()
        try:
            return queryset.get(key=self.kwargs["key"].lower())
        except Invitation.DoesNotExist:
            raise Http404()

    def get_queryset(self):
        return Invitation.objects.all_valid()



from django.conf.urls import patterns, url

from . import views

urlpatterns = patterns(
    '',

    url(r'^send-invite/$', views.SendInvite.as_view(),
        name='send-invite'),

    url(r'^send-json-invite/$', views.SendJSONInvite.as_view(),
        name='send-json-invite'),

    url(r'^accept-invite/(?P<key>\w+)/?$', views.AcceptInvite.as_view(),
        name='accept-invite'),
)



import datetime
import re
import json
from mock import patch

from django.test import TestCase
from django.test.client import RequestFactory
from django.test.utils import override_settings
from django.utils import timezone
from django.core.urlresolvers import reverse
from django.contrib.auth import get_user_model
from django.core import mail
from django.contrib.auth.models import AnonymousUser

from freezegun import freeze_time
from nose_parameterized import parameterized

from invitations.adapters import (
    get_invitations_adapter, BaseInvitationsAdapter)
from invitations.models import Invitation
from invitations.app_settings import app_settings
from invitations.views import AcceptInvite, SendJSONInvite
from invitations.forms import InviteForm


class InvitationModelTests(TestCase):

    @classmethod
    def setUpClass(cls):
        freezer = freeze_time('2015-07-30 12:00:06')
        freezer.start()
        cls.invitation = Invitation.create('email@example.com')
        freezer.stop()

    @classmethod
    def tearDownClass(cls):
        cls.invitation.delete()

    @freeze_time('2015-07-30 12:00:06')
    def test_create_invitation(self):
        self.assertEqual(self.invitation.email, 'email@example.com')
        self.assertIsNotNone(self.invitation.key)
        self.assertFalse(self.invitation.accepted)
        self.assertEqual(self.invitation.created, datetime.datetime.now())

    def test_invitation_key_expiry(self):
        self.invitation.sent = timezone.now() - datetime.timedelta(
            days=app_settings.INVITATION_EXPIRY, minutes=1)
        self.assertTrue(self.invitation.key_expired())
        self.invitation.sent = timezone.now() - datetime.timedelta(
            days=app_settings.INVITATION_EXPIRY, minutes=-1)
        self.assertFalse(self.invitation.key_expired())


class InvitationsAdapterTests(TestCase):

    @classmethod
    def setUp(cls):
        cls.adapter = get_invitations_adapter()

    @classmethod
    def tearDownClass(cls):
        del cls.adapter

    def test_fetch_adapter(self):
        self.assertIsInstance(self.adapter, BaseInvitationsAdapter)


class InvitationsSendViewTests(TestCase):

    @classmethod
    def setUp(cls):
        cls.user = get_user_model().objects.create_user(
            username='flibble',
            password='password')
        cls.existing_user = get_user_model().objects.create_user(
            username='flobble',
            password='password',
            email='flobble@example.com')
        cls.invitation = Invitation.create('invited@example.com')

    @classmethod
    def tearDownClass(cls):
        get_user_model().objects.all().delete()
        Invitation.objects.all().delete()

    def test_auth(self):
        response = self.client.post(
            reverse('invitations:send-invite'), {'email': 'valid@example.com'},
            follow=True)

        self.assertEqual(response.status_code, 404)

    @parameterized.expand([
        ('invalid@example', 'Enter a valid email address'),
        ('invited@example.com', 'This e-mail address has already been'),
        ('flobble@example.com', 'An active user is')
    ])
    def test_invalid_form_submissions(self, email, error):
        self.client.login(username='flibble', password='password')
        resp = self.client.post(
            reverse('invitations:send-invite'), {'email': email})

        form = resp.context_data['form']
        self.assertIn(error, form.errors['email'][0])

    @freeze_time('2015-07-30 12:00:06')
    def test_valid_form_submission(self):
        self.client.login(username='flibble', password='password')
        resp = self.client.post(
            reverse('invitations:send-invite'), {'email': 'email@example.com'})
        invitation = Invitation.objects.get(email='email@example.com')

        self.assertEqual(resp.status_code, 200)
        self.assertIn('success_message', resp.context_data.keys())

        self.assertEqual(invitation.sent, datetime.datetime.now())
        self.assertEqual(len(mail.outbox), 1)
        self.assertEqual(mail.outbox[0].to[0], 'email@example.com')
        self.assertIn('Invitation to join example.com', mail.outbox[0].subject)
        url = re.search(
            "(?P<url>/invitations/[^\s]+)", mail.outbox[0].body).group("url")
        self.assertEqual(url, reverse(
            'invitations:accept-invite', kwargs={'key': invitation.key}))


class InvitationsAcceptViewTests(TestCase):

    @classmethod
    def setUpClass(cls):
        cls.user = get_user_model().objects.create_user(
            username='flibble',
            password='password')
        cls.invitation = Invitation.create(
            'email@example.com', inviter=cls.user)

    @classmethod
    def tearDownClass(cls):
        get_user_model().objects.all().delete()
        Invitation.objects.all().delete()

    @override_settings(
        INVITATIONS_CONFIRM_INVITE_ON_GET=False
    )
    def test_accept_invite_get_disabled(self):
        resp = self.client.get(
            reverse(
                'invitations:accept-invite',
                kwargs={'key': self.invitation.key}),
            follow=True)
        self.assertEqual(resp.status_code, 404)

    @parameterized.expand([
        ('get'),
        ('post'),
    ])
    def test_accept_invite_invalid_key(self, method):
        client_with_method = getattr(self.client, method)
        resp = client_with_method(
            reverse('invitations:accept-invite', kwargs={'key': 'invalidKey'}),
            follow=True)
        self.assertEqual(resp.status_code, 404)

    @parameterized.expand([
        ('get'),
        ('post'),
    ])
    @override_settings(
        INVITATIONS_SIGNUP_REDIRECT='/non-existent-url/'
    )
    def test_accept_invite(self, method):
        client_with_method = getattr(self.client, method)
        resp = client_with_method(
            reverse('invitations:accept-invite',
                    kwargs={'key': self.invitation.key}), follow=True)
        invite = Invitation.objects.get(email='email@example.com')
        self.assertTrue(invite.accepted)
        self.assertEqual(invite.inviter, self.user)
        self.assertEqual(
            resp.request['PATH_INFO'], '/non-existent-url/')

    @override_settings(
        INVITATIONS_SIGNUP_REDIRECT='/non-existent-url/'
    )
    def test_signup_redirect(self):
        resp = self.client.post(
            reverse('invitations:accept-invite',
                    kwargs={'key': self.invitation.key}), follow=True)
        invite = Invitation.objects.get(email='email@example.com')
        self.assertTrue(invite.accepted)
        self.assertEqual(resp.request['PATH_INFO'], '/non-existent-url/')


class InvitationsSignalTests(TestCase):

    @classmethod
    def setUp(cls):
        cls.user = get_user_model().objects.create_user(
            username='flobble', password='password')
        cls.invite = Invitation.create(
            email='email@example.com', inviter=cls.user)

    @classmethod
    def tearDownClass(cls):
        cls.user.delete()
        cls.invite.delete()

    @patch('invitations.signals.invite_url_sent.send')
    def test_invite_url_sent_triggered_correctly(self, mock_signal):
        invite_url = reverse('invitations:accept-invite',
                             args=[self.invite.key])
        request = RequestFactory().get('/')
        invite_url = request.build_absolute_uri(invite_url)

        self.invite.send_invitation(request)

        self.assertTrue(mock_signal.called)
        self.assertEqual(mock_signal.call_count, 1)

        mock_signal.assert_called_with(
            instance=self.invite,
            invite_url_sent=invite_url,
            inviter=self.user,
            sender=Invitation,
        )

    @override_settings(
        INVITATIONS_SIGNUP_REDIRECT='/non-existent-url/'
    )
    @patch('invitations.signals.invite_accepted.send')
    def test_invite_invite_accepted_triggered_correctly(self, mock_signal):
        request = RequestFactory().get('/')
        self.invite.send_invitation(request)

        self.client.post(
            reverse('invitations:accept-invite',
                    kwargs={'key': self.invite.key}), follow=True)

        self.assertTrue(mock_signal.called)
        self.assertEqual(mock_signal.call_count, 1)

        self.assertEqual(
            mock_signal.call_args[1]['email'], 'email@example.com')
        self.assertEqual(
            mock_signal.call_args[1]['sender'], AcceptInvite)

        self.invite.delete()


class InvitationsFormTests(TestCase):

    @classmethod
    def setUp(cls):
        cls.accepted_invite = Invitation.create('already@accepted.com')
        cls.accepted_invite.accepted = True
        cls.accepted_invite.save()
        pending_invite = Invitation.create('pending@example.com')
        pending_invite.sent = timezone.now() - datetime.timedelta(
            days=app_settings.INVITATION_EXPIRY - 1)
        pending_invite.save()
        cls.existing_user = get_user_model().objects.create_user(
            username='flobble',
            password='password',
            email='flobble@example.com')

    @classmethod
    def tearDownClass(cls):
        get_user_model().objects.all().delete()
        Invitation.objects.all().delete()

    @parameterized.expand([
        ('bogger@something.com', True, None),
        ('already@accepted.com', False, 'has already accepted an invite'),
        ('pending@example.com', False, 'has already been invited'),
        ('flobble@example.com', False, 'active user is using this'),
    ])
    def test_form(self, email, form_validity, errors):
        form = InviteForm(data={'email': email})
        if errors:
            assert errors in str(form.errors)
        else:
            self.assertEqual(form.errors, {})
        self.assertEqual(form.is_valid(), form_validity)


class InvitationsManagerTests(TestCase):

    @classmethod
    def setUpClass(cls):
        cls.invitation1 = Invitation.create('email1@example.com')
        cls.invitation2 = Invitation.create('email2@example.com')
        cls.invitation3 = Invitation.create('email3@example.com')
        cls.invitation4 = Invitation.create('email4@example.com')
        cls.invitation1.accepted = True
        cls.invitation1.save()
        cls.invitation2.sent = timezone.now() - datetime.timedelta(
            days=app_settings.INVITATION_EXPIRY + 1)
        cls.invitation2.save()

    @classmethod
    def tearDownClass(cls):
        Invitation.objects.all().delete()

    def test_managers(self):
        valid = Invitation.objects.all_valid().values_list(
            'email', flat=True)
        expired = Invitation.objects.all_expired().values_list(
            'email', flat=True)
        expected_valid = ['email3@example.com', 'email4@example.com']
        expected_expired = ['email1@example.com', 'email2@example.com']

        self.assertEqual(sorted(valid), sorted(expected_valid))
        self.assertEqual(sorted(expired), sorted(expected_expired))

    def test_delete_all(self):
        valid = Invitation.objects.all_valid().values_list(
            'email', flat=True)
        Invitation.objects.delete_expired_confirmations()
        remaining_invites = Invitation.objects.all().values_list(
            'email', flat=True)
        self.assertEqual(sorted(valid), sorted(remaining_invites))


class InvitationsJSONTests(TestCase):

    @classmethod
    def setUp(cls):
        cls.user = get_user_model().objects.create_user(
            username='flibble',
            password='password',
            email='mrflibble@example.com')
        cls.accepted_invite = Invitation.create('already@accepted.com')
        cls.accepted_invite.accepted = True
        cls.accepted_invite.save()
        Invitation.create('email3@example.com')

    @classmethod
    def tearDownClass(cls):
        cls.user.delete()
        Invitation.objects.all().delete()

    @parameterized.expand([
        (['already@accepted.com'],
         {u'valid': [],
          u'invalid': [{u'already@accepted.com': u'already accepted'}]},
         400),
        (['xample.com'],
         {u'valid': [], u'invalid': [{u'xample.com': u'invalid email'}]},
         400),
        ('xample.com',
         {u'valid': [], u'invalid': []},
         400),
        (['email3@example.com'],
         {u'valid': [],
          u'invalid': [{u'email3@example.com': u'pending invite'}]},
         400),
        (['mrflibble@example.com'],
         {u'valid': [],
          u'invalid': [{u'mrflibble@example.com': u'user registered email'}]},
         400),
        (['example@example.com'],
         {u'valid': [{u'example@example.com': u'invited'}],
          u'invalid': []},
         201),
    ])
    @override_settings(
        INVITATIONS_ALLOW_JSON_INVITES=True
    )
    def test_post(self, data, expected, status_code):
        self.client.login(username='flibble', password='password')
        response = self.client.post(
            reverse('invitations:send-json-invite'),
            data=json.dumps(data),
            content_type='application/json')

        self.assertEqual(response.status_code, status_code)
        self.assertEqual(json.loads(response.content.decode()), expected)

    def test_json_setting(self):
        self.client.login(username='flibble', password='password')
        response = self.client.post(
            reverse('invitations:send-json-invite'),
            data=json.dumps(['example@example.com']),
            content_type='application/json')

        self.assertEqual(response.status_code, 404)

    @override_settings(
        INVITATIONS_ALLOW_JSON_INVITES=True
    )
    def test_anonymous_get(self):
        request = RequestFactory().get(
            reverse('invitations:send-json-invite'),
            content_type='application/json')
        request.user = AnonymousUser()
        response = SendJSONInvite.as_view()(request)

        self.assertEqual(response.status_code, 302)

    @override_settings(
        INVITATIONS_ALLOW_JSON_INVITES=True
    )
    def test_authenticated_get(self):
        request = RequestFactory().get(
            reverse('invitations:send-json-invite'),
            content_type='application/json')
        request.user = self.user
        response = SendJSONInvite.as_view()(request)

        self.assertEqual(response.status_code, 405)


class InvitationsAdminTests(TestCase):

    @classmethod
    def setUp(cls):
        cls.user = get_user_model().objects.create_superuser(
            username='flibble',
            password='password',
            email='mrflibble@example.com')
        cls.invite = Invitation.objects.create(email='example@example.com')

    @classmethod
    def tearDownClass(cls):
        cls.user.delete()
        Invitation.objects.all().delete()

    def test_admin_form_add(self):
        self.client.login(username='flibble', password='password')
        response = self.client.post(
            reverse('admin:invitations_invitation_add'),
            {'email': 'valid@example.com', 'inviter': self.user.id},
            follow=True)
        invite = Invitation.objects.get(email='valid@example.com')

        self.assertEqual(response.status_code, 200)
        self.assertTrue(invite.sent)
        self.assertEqual(invite.inviter, self.user)

        invite.delete()

    def test_admin_form_change(self):
        self.client.login(username='flibble', password='password')
        response = self.client.get(
            reverse('admin:invitations_invitation_change',
                    args=(self.invite.id,)),
            follow=True)

        self.assertEqual(response.status_code, 200)
        fields = list(response.context_data['adminform'].form.fields.keys())
        expected_fields = ['email', 'accepted', 'created',
                           'key', 'sent', 'inviter']
        self.assertEqual(fields, expected_fields)



from django.test import TestCase
from django.contrib.auth import get_user_model
from django.core.urlresolvers import reverse
from django.test.client import RequestFactory
from django.test.utils import override_settings

from nose_parameterized import parameterized
from allauth.account.models import EmailAddress

from invitations.models import Invitation, InvitationsAdapter
from invitations.adapters import get_invitations_adapter


class AllAuthIntegrationTests(TestCase):

    @classmethod
    def setUpClass(cls):
        cls.user = get_user_model().objects.create_user(
            username='flibble',
            password='password')
        cls.invitation = Invitation.create(
            'email@example.com', inviter=cls.user)
        cls.adapter = get_invitations_adapter()

    @classmethod
    def tearDownClass(cls):
        get_user_model().objects.all().delete()
        Invitation.objects.all().delete()

    @parameterized.expand([
        ('get'),
        ('post'),
    ])
    def test_accept_invite_allauth(self, method):
        client_with_method = getattr(self.client, method)
        resp = client_with_method(
            reverse('invitations:accept-invite',
                    kwargs={'key': self.invitation.key}), follow=True)
        invite = Invitation.objects.get(email='email@example.com')
        self.assertTrue(invite.accepted)
        self.assertEqual(invite.inviter, self.user)
        self.assertEqual(
            resp.request['PATH_INFO'], reverse('account_signup'))

        form = resp.context_data['form']
        self.assertEqual('email@example.com', form.fields['email'].initial)
        messages = resp.context['messages']
        message_text = [message.message for message in messages]
        self.assertEqual(
            message_text, [
                'Invitation to - email@example.com - has been accepted'])

        resp = self.client.post(
            reverse('account_signup'),
            {'email': 'email@example.com',
             'username': 'username',
             'password1': 'password',
             'password2': 'password'
             })

        allauth_email_obj = EmailAddress.objects.get(
            email='email@example.com')
        self.assertTrue(allauth_email_obj.verified)

    def test_fetch_adapter(self):
        self.assertIsInstance(self.adapter, InvitationsAdapter)

    def test_allauth_signup_open(self):
        signup_request = RequestFactory().get(reverse(
            'account_signup', urlconf='allauth.account.urls'))
        self.assertTrue(
            self.adapter.is_open_for_signup(signup_request))

    @override_settings(
        INVITATIONS_INVITATION_ONLY=True,
    )
    def test_allauth_adapter_invitations_only(self):
        signup_request = RequestFactory().get(reverse(
            'account_signup', urlconf='allauth.account.urls'))
        self.assertFalse(
            self.adapter.is_open_for_signup(signup_request))
        response = self.client.get(
            reverse('account_signup'))
        self.assertIn('Sign Up Closed', response.content.decode('utf8'))



from setuptools import setup, find_packages

setup(
    name='django-invitations',
    packages=find_packages(),
    package_data={'invitations': ['templates/*.*']},
    include_package_data=True,
    zip_safe=False,
    version='1.6',
    description='Generic invitations app with support for django-allauth',
    author='https://github.com/bee-keeper',
    author_email='none@none.com',
    url='https://github.com/bee-keeper/django-invitations.git',
    download_url='https://github.com/'
                 'bee-keeper/django-invitations/tarball/1.6',
    keywords=['django', 'invitation', 'django-allauth', 'invite'],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Environment :: Web Environment',
        'Topic :: Internet',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Framework :: Django',
    ],
    install_requires=[
        'django-braces>=1.8.0',
    ],
)



from django.contrib import admin

from .models import Invitation
from .forms import InvitationAdminAddForm, InvitationAdminChangeForm


class InvitationAdmin(admin.ModelAdmin):
    list_display = ('email', 'sent', 'accepted')

    def get_form(self, request, obj=None, **kwargs):
        if obj:
            kwargs['form'] = InvitationAdminChangeForm
        else:
            kwargs['form'] = InvitationAdminAddForm
            kwargs['form'].user = request.user
            kwargs['form'].request = request
        return super(InvitationAdmin, self).get_form(request, obj, **kwargs)

admin.site.register(Invitation, InvitationAdmin)
